@@ -120,7 +120,9 @@ def _fill_index_names(
     start_row: int = 2 if horizontal else 1
 
     index_names: pd.Index = (
-        index if horizontal else index.get_level_values(level=1)
+        index
+        if (horizontal or isinstance(index, pd.Index))
+        else index.get_level_values(level=1)
     )
 
     for idx, name in enumerate(index_names, start=start_row):
@@ -283,7 +285,11 @@ class Table:
         )
 
     def render(self, document: Document) -> Document:
-        document = render_table(
+        heading = document.add_heading(self._title, level=2)
+        heading.alignment = CENTER
+        heading.runs[0].font.size = Pt(10)
+
+        render_table(
             self._data,
             self._color,
             self._shade,
